#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 row-types
version:              1.0.1.2
visibility:           public
id:                   row-types-1.0.1.2-EDHNGNVcJZlDbUmZXUbK5h
key:                  row-types-1.0.1.2-EDHNGNVcJZlDbUmZXUbK5h
license:              MIT
maintainer:           dwincort@gmail.com
author:               Daniel Winograd-Cort, Matthew Farkas-Dyck
homepage:             https://github.com/target/row-types
synopsis:             Open Records and Variants
description:
    This package uses closed type families and type literals to implement open
    records and variants.
    The core is based off of the <https://hackage.haskell.org/package/CTRex CTRex>
    package, but it also includes polymorphic variants and a number of
    additional functions.  That said, it is not a proper superset of CTRex as it
    specifically forbids records from having more than one element of the same
    label.

category:             Data, Data Structures
abi:                  667da1c33612558c24e8f8638e818d55
exposed:              True
exposed-modules:
    Data.Row Data.Row.Dictionaries Data.Row.Internal Data.Row.Records
    Data.Row.Switch Data.Row.Variants

import-dirs:          /usr/lib/ghc-9.6.6/site-local/row-types-1.0.1.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/row-types-1.0.1.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/row-types-1.0.1.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-row-types
hs-libraries:         HSrow-types-1.0.1.2-EDHNGNVcJZlDbUmZXUbK5h
depends:
    base-4.18.2.1 constraints-0.14.3-FhBPa84LIoyEg8maZC39ri
    deepseq-1.4.8.1 generic-lens-2.2.2.0-54jvll4yuvYKNqNsExkZML
    hashable-1.4.7.0-JuZCUcgZ6993MAquoa2cCW
    profunctors-5.6.3-9BLFPFHf8vY849ipqks6S6 text-2.0.2
    unordered-containers-0.2.20.1-24qNbjJ9xXJll0vtFCYfq

haddock-interfaces:   /usr/share/doc/haskell-row-types/html/row-types.haddock
haddock-html:         /usr/share/doc/haskell-row-types/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

